# uds_connect

`uds_connect` is a Python package for interacting with UDS (Unified Diagnostic Services) over various CAN interfaces, such as `peak`, `kvaser`, and `vector`.

## Installation

```bash
pip install uds_connect
